@@ -19,11 +19,15 @@ A number containing the new mapped value.
 ```
 * use lib_rapid::math;
 *
-* let result: i32 = rapidmath::map(5., 0., 10., 0., 1.); // Original value 5 in the range from 0-10
+* let result: i32 = math::rapidmath::map(5., 0., 10., 0., 1.); // Original value 5 in the range from 0-10
 * std::println!("{}", result.to_string()) // Prints "0.5"
 * ```
 */
-pub fn map<T: NumOps + Copy>(value: T, start1: T, end1: T, start2: T, end2: T) -> T {
+pub fn map_to<T: NumOps + Copy>(value: T, start1: T, end1: T, start2: T, end2: T) -> T {
 
     (start2 + (end2 - start2)) * ((value - start1) / end1 - start1)
+}
+
+pub fn dec_lshift<T: std::ops::Add<Output = T> + std::ops::Shl<usize, Output = T> + Copy >(n: T) -> T {
+    (n << 1) + (n << 3)
 }
\ No newline at end of file
